!  DLL DipolarTripletIntensities.f90 
!
!  FUNCTIONS/SUBROUTINES exported from DLLDipolarTripletIntensities.dll:
!  DLLDipolarTripletIntensities - subroutine 
!
subroutine DLLDipolarTripletIntensities (i, j, lvector, gvector, eigenvectorsreal, eigenvectorscmpx, intensities)

  ! This subroutine calculates transition probabilities (perpendicular and parallel mode)
  ! for any transition within the 9-level system of 2 interacting S=1 systems
  ! @ WRHagen 2022 07 23
  !
    IMPLICIT NONE
  !DEC$ ATTRIBUTES DLLEXPORT::DLLDipolarTripletIntensities
  !DEC$ ATTRIBUTES STDCALL::DLLDipolarTripletIntensities

  ! Declare calling parameters
    INTEGER*4   i, j
    REAL*8      lvector(3), gvector(3)
    REAL*8      eigenvectorsreal(9,9), eigenvectorscmpx(9,9)
    REAL*8      intensities(2)
    
  ! Declare local parameters
    COMPLEX*8   cm(9,9), smin, spls, sz, sy, sx
    REAL*8      sq2, xl, yl, zl, gx, gy, gz, perp, parl

 ! Body of DLLDipolar2
    sq2 =   SQRT(2.)
    xl =    lvector(1)
    yl =    lvector(2)
    zl =    lvector(3)
    gx =    gvector(1)
    gy =    gvector(2)
    gz =    gvector(3)

    FORALL (i=1:9, j=1:9)
        cm(i,j) = CMPLX(eigenvectorsreal(i,j), eigenvectorscmpx(i,j))
    END FORALL

    spls = CONJG(cm(1,i))*cm(4,j)+CONJG(cm(2,i))*cm(5,j)+CONJG(cm(3,i))*cm(6,j)+CONJG(cm(4,i))*cm(7,j)+CONJG(cm(5,i))*cm(8,j)+CONJG(cm(6,i))*cm(9,j)
    spls = sq2*spls
    smin = CONJG(cm(4,i))*cm(1,j)+CONJG(cm(5,i))*cm(2,j)+CONJG(cm(6,i))*cm(3,j)+CONJG(cm(7,i))*cm(4,j)+CONJG(cm(8,i))*cm(5,j)+CONJG(cm(9,i))*cm(6,j)
    smin = sq2*smin
    sz   = CONJG(cm(1,i))*cm(1,j)+CONJG(cm(2,i))*cm(2,j)+CONJG(cm(3,i))*cm(3,j)-CONJG(cm(7,i))*cm(7,j)-CONJG(cm(8,i))*cm(8,j)-CONJG(cm(9,i))*cm(9,j)
    
    sx =    (spls + smin) / 2.
    sy =    (spls - smin) / 2. / (0., 1.)
    
    sx =    sx * gx
    sy =    sy * gy
    sz =    sz * gz
    
    CALL intens (sx, sy, sz, xl, yl, zl, perp, parl)
    
    intensities(1) = perp
    intensities(2) = parl
    
    RETURN

end subroutine DLLDipolarTripletIntensities
